@@ -48,8 +48,13 @@ class ExitView(BaseWebView):
 
 
 if __name__ == '__main__':
-    log = logging.getLogger()
-    log.name = 'main'
+    logger = logging.getLogger()
+    logger.name = 'main'
+
+    # web requests logger
+    reqlog = logging.getLogger('%s.requests' % logger.name)
+    reqlog.handlers = [logging.StreamHandler(sys.stdout)]
+
     try:
         pr = ArgumentParser(prog=None)
         pr.add_argument(
@@ -58,14 +63,14 @@ if __name__ == '__main__':
         args = pr.parse_args()
 
         if args.debug > 0:
-            log.setLevel(logging.DEBUG)
+            logger.setLevel(logging.DEBUG)
 
         cfg = {
             'secret_key': "0123456789ABCDEF",
             'max_content_length': 10485760,
             'templates_auto_reload': bool(args.debug >= 3),
         }
-        webapp = BaseWebApp(options=cfg, logger=log, debug=args.debug)
+        webapp = BaseWebApp(options=cfg, logger=logger, debug=args.debug)
         webapp.views = [
             IndexView, HomeView,
             ExitView,
@@ -74,5 +79,5 @@ if __name__ == '__main__':
         webapp.start('0.0.0.0', 8000)
 
     except Exception:
-        log.fatal(format_exc())
+        logger.fatal(format_exc())
         sys.exit(1)
